@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,7 +57,7 @@ import com.openexchange.exceptions.osgi.ComponentRegistration;
 
 /**
  * {@link DataRetentionActivator} - Simple {@link BundleActivator activator} which registers data retention bundle's exception class.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class DataRetentionActivator implements BundleActivator {
@@ -71,7 +71,7 @@ public final class DataRetentionActivator implements BundleActivator {
         super();
     }
 
-    public void start(BundleContext context) throws Exception {
+    public void start(final BundleContext context) throws Exception {
         componentRegistration = new ComponentRegistration(
             context,
             DataRetentionException.DATA_RETENTION_COMPONENT,
